import { UUIIconHost } from './UUIIconHost';
export declare class UUIIconRegistry {
    private icons;
    /**
     * Attach an element to provide this registry. Use detach when disconnected.
     * @param {EventTarget} element the element of which to provide this icon-set.
     */
    attach(element: EventTarget): void;
    /**
     * Detach an element from providing this registry.
     * @param {EventTarget} element the element of which to stop providing this icon-set.
     */
    detach(element: EventTarget): void;
    private _onIconRequest;
    /**
     * Define a icon to be served by this registry.
     * @param {string} iconName the name to use for this icon.
     * @param {string} svgString the svg source for this icon.
     */
    defineIcon(iconName: string, svgString: string): void;
    /**
     * Retrieve the SVG source of an icon, Returns ´null´ if the name does not exist.
     * @param {string} iconName the name of the icon to retrieve.
     */
    getIcon(iconName: string): Promise<string> | null;
    /**
     * Declare that this registry will be providing a icon for this name
     * @param {string} iconName the name of the icon to be provided.
     */
    protected provideIcon(iconName: string): UUIIconHost;
    /**
     * extend this method to provide your own logic.
     * @param iconName
     * @returns
     */
    protected acceptIcon(iconName: string): boolean;
    /**
     * Dynamic concept by extending this class:
     * extend getIcon in this way:
  
      protected acceptIcon(iconName: string): boolean {
  
        // Check if this is something we want to accept and provide.
        if(iconName === "myCustomIcon") {
  
          // Inform that we will be providing this.
          const icon = this.provideIcon(iconName);
  
          // When data is available set it on this icon object, this can be done at any point in time:
          icon.svg = "...";
  
          return true;
        }
  
        return false;
      }
    */
    getIconNames(): string[];
}
